Court Opinions: Index

| ## ## 2015 Index Listing of Maryland Court of Appeals Opinions

Thu Aug 13 13:16:32 EDT 2015

CASE PDF docket/term | CITATION | FILED | JUDGE | PARTIES | Line
--- | --- | --- | --- | --- | ---
33ag/15 | . | 2015-08-13 | Order | Attorney Grievance v. Galbraith | 1
85/14 | . | 2015-08-11 | Greene | Varriale v. State | 2
5ag/15 | . | 2015-08-10 | Order | Attorney Grievance v. Scott | 3
55/14 | . | 2015-08-06 | McDonald | Bontempo v. Lare | 4
22ag/14 | . | 2015-08-06 | Greene | Attorney Grievance v. Shephard | 5
93pc/14 | . | 2015-08-04 | PC Order | State v. Royal | 6
88/14 | . | 2015-08-04 | Adkins | Griffin v. Lindsey | 7
43/14 | . | 2015-07-27 | McDonald | Sinclair v. State | 8
13/14 | . | 2015-07-27 | McDonald | Peterson v. State | 9
34ag/14 | . | 2015-07-27 | McDonald | Attorney Grievance v. Trye | 10
80/14 | . | 2015-07-27 | Harrell | Preston v. State | 11
18ag/13 | . | 2015-07-27 | Harrell | Attorney Grievance v. Hamilton | 12
56ag/13 | . | 2015-07-27 | Greene | Attorney Grievance v. Gray | 13
7/14 | . | 2015-07-27 | Barbera | Spence v. State | 14
11/14 | . | 2015-07-27 | Barbera | Demby v. State | 15
65/14 | . | 2015-07-27 | Barbera | Counts v. State | 16
87/14 | . | 2015-07-24 | Watts | Cooper v. Rodriguez | 17
9ag/14 | . | 2015-07-24 | Watts | Attorney Grievance v. Haley | 18
82/14 | . | 2015-07-24 | Adkins | Scarfield v. Muntjan | 19
47/14 | . | 2015-07-13 | Per Curiam | State v. Smith | 20
26ag/15 | . | 2015-07-10 | Order | Attorney Grievance v. Reyes | 21
3ag/15 | . | 2015-07-10 | Order | Attorney Grievance v. Killian | 22
67/14 | . | 2015-07-09 | Battaglia | State v. Norton | 23
14ag/14 | . | 2015-06-30 | Watts | Attorney Grievance v. Shuler | 24
68/14 | . | 2015-06-29 | Greene | Ford v. Antwerpen Motorcars | 25
108ag/14 | . | 2015-06-25 | Order | Attorney Grievance v. Gertner | 26
84/14 | . | 2015-06-25 | Battaglia | Dept. of State Police v. Dashiell | 27
109ag/14 | . | 2015-06-24 | Order | Attorney Grievance v. Chirumbole | 28
5ag/14 | . | 2015-06-23 | McDonald | Attorney Grievance v. Van Dusen | 29
73ag/13 | . | 2015-06-23 | McDonald | Attorney Grievance v. Smith | 30
71/14 | . | 2015-06-23 | Adkins | Windesheim v. Larocca | 31
6ag/14 | . | 2015-06-23 | Adkins | Attorney Grievance v. Katz | 32
83/14 | . | 2015-06-18 | Watts | Hranicka v. Chesapeake Surgical | 33
69/14 | . | 2015-06-18 | Harrell | WSSC v. Lafarge North America | 34
72/14 | . | 2015-06-18 | Harrell | State v. Hunt & Hardy | 35
101ag/14 | . | 2015-06-17 | Order | Resignation of Wees | 36
11ag/15 | . | 2015-06-17 | Order | Reinstatement of Joseph | 37
105ag/14 | . | 2015-06-09 | Order | Attorney Grievance v. Peklo | 38
6ag/15 | . | 2015-06-09 | Order | Attorney Grievance v. Floam | 39
9agpc/14 | . | 2015-06-05 | PC Order | Attorney Grievance v. Haley | 40
62ag/14 | . | 2015-06-05 | Order | Attorney Grievance v. Baylor | 41
39m/14 | . | 2015-06-05 | Order | Application of Tabiei | 42
76ag/14 | . | 2015-06-04 | Order | Attorney Grievance v. Ramsey | 43
57/14 | 443 Md. 199 | 2015-06-03 | Greene | Bd. of Pub. Works v. K. Hovnanian's Four Seasons | 44
21ag/15 | 443 Md. 198 | 2015-06-01 | Order | Attorney Grievance v. Kang | 45
77/14 | 443 Md. 177 | 2015-05-28 | McDonald | Wilcox v. Orellano | 46
52/14 | 443 Md. 93 | 2015-05-27 | Greene | Woznicki v. GEICO; Morse v. Erie Insurance | 47
75/14 | 443 Md. 148 | 2015-05-27 | Battaglia | Shader v. Hampton Improvement Ass'n | 48
76/14 | 443 Md. 47 | 2015-05-22 | Watts | Thompson v. UBS Financial Servs. | 49

66/14 | 443 Md. 15 | 2015-05-22 | Watts | Breeding v. Koste | 50
63/14 | 443 Md. 1 | 2015-05-22 | Adkins | Bonilla v. State | 51
86ag/09 | 443 Md. 75 | 2015-05-22 | Adkins | Attorney Grievance v. Eckel | 52
18agpc/13 | 442 Md. 740 | 2015-05-13 | PC Order | Attorney Grievance v. Hamilton | 53
14ag/15 | 442 Md. 741 | 2015-05-13 | Order | Attorney Grievance v. Baber | 54
6agpc/14 | 442 Md. 737 | 2015-05-11 | PC Order | Attorney Grievance v. Katz | 55
77ag/14 | 442 Md. 439 | 2015-05-11 | Order | Attorney Grievance v. McDaniel | 56
100ag/14 | 442 Md. 738 | 2015-05-11 | Order | Attorney Grievance v. Aquia | 57
5agpc/14 | 442 Md. 736 | 2015-05-08 | PC Order | Attorney Grievance v. Van Dusen | 58
64ag/14 | 442 Md. 684 | 2015-05-01 | Order | Attorney Grievance v. Burkhardt | 59
42/14 | 442 Md. 632 | 2015-04-23 | Battaglia | Sublet, Harris & Monge-Martinez v. State | 60
4m/14 | 442 Md. 716 | 2015-04-22 | Battaglia | State v. G & C Gulf | 61
39/14 | 442 Md. 595 | 2015-04-21 | Harrell | Anne Arundel Co. v. Harwood Civic Ass'n | 62
29/14 | 442 Md. 539 | 2015-04-21 | Harrell | Anne Arundel Co. v. Bell | 63
56/14 | 442 Md. 616 | 2015-04-21 | Battaglia | State v. Yancey | 64
51/14 | 442 Md. 685 | 2015-04-21 | Adkins | Md. Casualty v. Blackstone Int'l. | 65
44/14 | 442 Md. 518 | 2015-04-20 | McDonald | Baltimore Co. v. Thiergartner; Walters v. Balt. Co. | 66
62/14 | 442 Md. 488 | 2015-04-17 | Watts | Hailes v. State | 67
45/14 | 442 Md. 466 | 2015-04-17 | Harrell | Connors v. Gov't Employees Ins. Co. | 68
94ag/14 | 442 Md. 465 | 2015-04-07 | Order | Attorney Grievance v. Rollison | 69
22/14 | 442 Md. 446 | 2015-04-07 | Barbera | Simpson v. State | 70
48/14 | 442 Md. 419 | 2015-04-01 | Greene | State v. Manion | 71
38/14 | 442 Md. 384 | 2015-03-30 | McDonald | Payne v. Erie Insurance Exch. | 72
31/14 | 442 Md. 289 | 2015-03-30 | McDonald | Metro Maintenance Systems v. Milburn | 73
49/14 | 442 Md. 354 | 2015-03-30 | Harrell | In re: Tyrell A. | 74
40/14 | 442 Md. 254 | 2015-03-30 | Harrell | Harrison-Solomon v. State | 75
35/14 | 442 Md. 311 | 2015-03-30 | Greene | Espina v. Jackson | 76
53/14 | 442 Md. 211 | 2015-03-27 | Watts | State v. Johnson | 77
41/14 | 442 Md. 226 | 2015-03-27 | Watts | Garner v. State | 78
64ag/13 | 442 Md. 197 | 2015-03-27 | Watts | Attorney Grievance v. Marcalus | 79
83ag/14 | 442 Md. 193 | 2015-03-26 | Order | Reinstatement of Holt | 80
63ag/14 | 442 Md. 192 | 2015-03-13 | Order | Attorney Grievance v. McNally | 81
37/14 | 442 Md. 168 | 2015-03-09 | Battaglia | Smiley v. State | 82
85ag/13 | 442 Md. 167 | 2015-03-04 | Order | Attorney Grievance v. Wray | 83
15ag/14 | 442 Md. 151 | 2015-03-04 | Harrell | Attorney Grievance v. Burghardt | 84
92pc/14 | 442 Md. 150 | 2015-03-02 | PC Order | Fuller v. Republican Central Comm. | 85
1m/14 | 442 Md. 67 | 2015-03-02 | Harrell | Antonio v. SSA Security | 86
86ag/12 | 442 Md. 91 | 2015-03-02 | Battaglia | Attorney Grievance v. Barton | 87
21pc/14 | 442 Md. 55 | 2015-02-24 | PC Order | People's Insurance Counsel v. State Farm | 88
38ag/14 | 442 Md. 66 | 2015-02-24 | Order | Attorney Grievance v. James | 89
30ag/13 | 441 Md. 703 | 2015-02-23 | Watts | Attorney Grievance v. Basinger | 90
89ag/14 | 442 Md. 54 | 2015-02-23 | Order | Attorney Grievance v. Worthy | 91
23/14 | 441 Md. 673 | 2015-02-23 | McDonald | Oglesby v. State | 92
3ag/13 | 442 Md. 14 | 2015-02-23 | McDonald | Attorney Grievance v. Smith | 93
1ag/14 | 442 Md. 1 | 2015-02-23 | Adkins | Attorney Grievance v. Cocco | 94
5m/14 | 441 Md. 671 | 2015-02-20 | Greene | Schlossberg v. Bell Builders Remodeling | 95
88ag/14 | 441 Md. 664 | 2015-02-13 | Order | Attorney Grievance v. Shields | 96
64agpc/13 | 441 Md. 619 | 2015-02-05 | PC Order | Attorney Grievance v. Marcalus | 97
72ag/12 | 441 Md. 590 | 2015-02-05 | Barbera | Attorney Grievance v. Adams | 98
25/14 | 441 Md. 560 | 2015-02-04 | Adkins | Amalgam. Trans. Union v. Lovelace | 99

7ag/13 | 441 Md. 416 | 2015-02-02 | Battaglia | Attorney Grievance v. Mixter | 100
83ag/13 | 441 Md. 367 | 2015-01-30 | Harrell | Attorney Grievance v. Shapiro | 101
19/14 | 441 Md. 621 | 2015-01-29 | Greene | Rounds v. M-NCPPC | 102
82ag/14 | 441 Md. 366 | 2015-01-28 | Order | Attorney Grievance v. Alonso | 103
21ag/14 | 441 Md. 351 | 2015-01-27 | Order | Attorney Grievance v. Green | 104
27/14 | 441 Md. 310 | 2015-01-27 | Harrell | Cunningham v. Feinberg | 105
48ag/13 | 441 Md. 248 | 2015-01-27 | Greene | Attorney Grievance v. Olszewski | 106
31ag/13 | 441 Md. 352 | 2015-01-27 | Greene | Attorney Grievance v. Butler | 107
30/14 | 441 Md. 290 | 2015-01-27 | Battaglia | Falls Garden Condo. v. Falls Homeowners | 108
26/14 | 441 Md. 275 | 2015-01-27 | Adkins | Kelly v. Duvall | 109
12ag/14 | 441 Md. 237 | 2015-01-26 | Adkins | Attorney Grievance v. Buehler | 110
28/14 | 441 Md. 220 | 2015-01-23 | Watts | State v. Callahan | 111
48ag/14 | 441 Md. 216 | 2015-01-22 | Order | Attorney Grievance v. Phillips | 112
37ag/14 | 441 Md. 214 | 2015-01-16 | Order | Attorney Grievance v. Brigerman | 113
44ag/14 | 441 Md. 213 | 2015-01-15 | Order | Attorney Grievance v. Olander | 114
74ag/14 | 441 Md. 212 | 2015-01-13 | Order | Attorney Grievance v. Feldman | 115

[ Home | Site Index | Opinions | Search | Jobs ]